<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>HideAllBlocks</name>
    <message>
        <source>&amp;Hide All</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Zablokuj wszystko
&amp;Ukryj wszystko</translatorcomment>
        <translation type="obsolete">&amp;Ukryj wszystko</translation>
    </message>
    <message>
        <location filename="../HideAllBlocksInit.js" line="+2"/>
        <source>&amp;Hide All Blocks</source>
        <translation>&amp;Ukryj wszystkie bloki</translation>
    </message>
</context>
</TS>
